@@ -1,10 +1,8 @@
 package File::Find::Object::Base;
-
+$File::Find::Object::Base::VERSION = '0.3.3';
 use strict;
 use warnings;
 
-our $VERSION = 'v0.3.2';
-
 use integer;
 
 # TODO :
@@ -12,16 +10,15 @@ use integer;
 # add a regression test to test it.
 #
 
-use Class::XSAccessor
-    accessors => {
-        (map
-            { $_ => $_ }
-            (qw(
+use Class::XSAccessor accessors => {
+    (
+        map { $_ => $_ } (
+            qw(
                 _last_dir_scanned
-            ))
+                )
         )
-    }
-    ;
+    )
+};
 
 use File::Spec;
 
@@ -30,20 +27,22 @@ use File::Spec;
 
 sub _make_copy_methods
 {
-    my ($pkg, $methods) = @_;
+    my ( $pkg, $methods ) = @_;
 
+    ## no critic
     no strict 'refs';
     foreach my $method (@$methods)
     {
-        *{$pkg."::".$method."_copy"} =
-            do {
-                my $m = $method;
-                sub {
-                    my $self = shift;
-                    return [ @{$self->$m(@_)} ];
-                };
+        *{ $pkg . "::" . $method . "_copy" } = do
+        {
+            my $m = $method;
+            sub {
+                my $self = shift;
+                return [ @{ $self->$m(@_) } ];
             };
+        };
     }
+    ## use critic
     return;
 }
 
@@ -55,19 +54,19 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-File::Find::Object::Base - base class for File::Find::Object
-
 =head1 VERSION
 
-version v0.3.2
+version 0.3.3
 
 =head1 DESCRIPTION
 
 This is the base class for F::F::O classes. It only defines some accessors,
 and is for File::Find::Object's internal use.
 
+=head1 NAME
+
+File::Find::Object::Base - base class for File::Find::Object
+
 =head1 METHODS
 
 =head1 SEE ALSO
@@ -89,38 +88,10 @@ http://www.perlfoundation.org/legal/licenses/artistic-2_0.html
 
 3. At your option - any later version of either or both of these licenses.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2000 by Olivier Thauvin and others.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Find-Object or by email to
-bug-file-find-object@rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc File::Find::Object
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -134,7 +105,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/File-Find-Object>
+L<https://metacpan.org/release/File-Find-Object>
 
 =item *
 
@@ -170,14 +141,6 @@ L<http://cpanratings.perl.org/d/File-Find-Object>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/File-Find-Object>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -188,7 +151,7 @@ L<http://cpants.cpanauthors.org/dist/File-Find-Object>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/F/File-Find-Object>
 
@@ -222,8 +185,29 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-file-find-object>
+L<https://github.com/shlomif/perl-file-find-object>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-file-find-object
+  git clone git://github.com/shlomif/perl-file-find-object.git
+
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-file-find-object/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2000 by Olivier Thauvin and others.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
