@@ -1,19 +1,16 @@
 package File::Find::Object::PathComp;
-
+$File::Find::Object::PathComp::VERSION = '0.3.3';
 use strict;
 use warnings;
 
-our $VERSION = 'v0.3.2';
-
 use integer;
 
 use parent 'File::Find::Object::Base';
 
-use Class::XSAccessor
-    accessors => {
-        (map
-            { $_ => $_ }
-            (qw(
+use Class::XSAccessor accessors => {
+    (
+        map { $_ => $_ } (
+            qw(
                 _actions
                 _curr_file
                 _files
@@ -21,19 +18,23 @@ use Class::XSAccessor
                 _open_dir_ret
                 _stat_ret
                 _traverse_to
-            ))
+                )
         )
+    )
     },
-    getters => { _inodes => '_inodes' },
+    getters => { _inodes     => '_inodes' },
     setters => { _set_inodes => '_inodes' },
     ;
 
 use File::Spec;
 
-__PACKAGE__->_make_copy_methods([qw(
-        _files
-        _traverse_to
-    )]
+__PACKAGE__->_make_copy_methods(
+    [
+        qw(
+            _files
+            _traverse_to
+            )
+    ]
 );
 
 sub _dev
@@ -49,29 +50,25 @@ sub _inode
 sub _is_same_inode
 {
     my $self = shift;
+
     # $st is an array ref with the return of perldoc -f stat .
     my $st = shift;
 
     # On MS-Windows, all inodes in stat are returned as 0, so we need to
     # check that both inodes are not zero. This is why there's the
     # $self->_inode() != 0 check at the end.
-    return
-    (
-        $self->_dev() == $st->[0]
-     && $self->_inode() == $st->[1]
-     && $self->_inode() != 0
-    );
+    return (   $self->_dev() == $st->[0]
+            && $self->_inode() == $st->[1]
+            && $self->_inode() != 0 );
 }
 
 sub _should_scan_dir
 {
-    my $self = shift;
+    my $self    = shift;
     my $dir_str = shift;
 
-    if (defined($self->_last_dir_scanned()) &&
-        ($self->_last_dir_scanned() eq $dir_str
-       )
-    )
+    if ( defined( $self->_last_dir_scanned() )
+        && ( $self->_last_dir_scanned() eq $dir_str ) )
     {
         return;
     }
@@ -84,30 +81,31 @@ sub _should_scan_dir
 
 sub _set_up_dir
 {
-    my $self = shift;
+    my $self    = shift;
     my $dir_str = shift;
 
-    $self->_files($self->_calc_dir_files($dir_str));
+    $self->_files( $self->_calc_dir_files($dir_str) );
 
-    $self->_traverse_to($self->_files_copy());
+    $self->_traverse_to( $self->_files_copy() );
 
     return $self->_open_dir_ret(1);
 }
 
 sub _calc_dir_files
 {
-    my $self = shift;
+    my $self    = shift;
     my $dir_str = shift;
 
     my $handle;
     my @files;
-    if (!opendir($handle, $dir_str))
+    if ( !opendir( $handle, $dir_str ) )
     {
         # Handle this error gracefully.
     }
     else
     {
-        @files = (sort { $a cmp $b } File::Spec->no_upwards(readdir($handle)));
+        @files =
+            ( sort { $a cmp $b } File::Spec->no_upwards( readdir($handle) ) );
         closedir($handle);
     }
 
@@ -116,10 +114,10 @@ sub _calc_dir_files
 
 sub _component_open_dir
 {
-    my $self = shift;
+    my $self    = shift;
     my $dir_str = shift;
 
-    if (!$self->_should_scan_dir($dir_str))
+    if ( !$self->_should_scan_dir($dir_str) )
     {
         return $self->_open_dir_ret();
     }
@@ -131,7 +129,7 @@ sub _next_traverse_to
 {
     my $self = shift;
 
-    return shift(@{$self->_traverse_to()});
+    return shift( @{ $self->_traverse_to() } );
 }
 
 1;
@@ -142,19 +140,19 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-File::Find::Object::PathComp - base class for File::Find::Object's Path Components
-
 =head1 VERSION
 
-version v0.3.2
+version 0.3.3
 
 =head1 DESCRIPTION
 
 This is the base class for F::F::O's path components. It only defines some
 accessors, and is for File::Find::Object's internal use.
 
+=head1 NAME
+
+File::Find::Object::PathComp - base class for File::Find::Object's Path Components
+
 =head1 METHODS
 
 =head1 SEE ALSO
@@ -176,38 +174,10 @@ http://www.perlfoundation.org/legal/licenses/artistic-2_0.html
 
 3. At your option - any later version of either or both of these licenses.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2000 by Olivier Thauvin and others.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Find-Object or by email to
-bug-file-find-object@rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc File::Find::Object
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -221,7 +191,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/File-Find-Object>
+L<https://metacpan.org/release/File-Find-Object>
 
 =item *
 
@@ -257,14 +227,6 @@ L<http://cpanratings.perl.org/d/File-Find-Object>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/File-Find-Object>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -275,7 +237,7 @@ L<http://cpants.cpanauthors.org/dist/File-Find-Object>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/F/File-Find-Object>
 
@@ -309,8 +271,29 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-file-find-object>
+L<https://github.com/shlomif/perl-file-find-object>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-file-find-object
+  git clone git://github.com/shlomif/perl-file-find-object.git
+
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-file-find-object/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2000 by Olivier Thauvin and others.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
